@@ -1,3 +1,8 @@
+import type { DefaultError } from "@tanstack/query-core";
+import { queryOptions, type UseMutationOptions } from "@tanstack/react-query";
+import { CircleAlert } from "lucide-react";
+import type React from "react";
+import { Fragment } from "react";
 import { DelayedButton } from "@/components/DelayedButton";
 import { ExternalLink } from "@/components/ExternalLink";
 import { Button } from "@/components/ui/button";
@@ -24,11 +29,6 @@ import { queryClient } from "@/lib/query-client";
 import { toastInfo, toastSuccess, toastThrownError } from "@/lib/toast";
 import { groupBy, keyComparator } from "@/lib/utils";
 import { compareVersion, toVersionString } from "@/lib/version";
-import type { DefaultError } from "@tanstack/query-core";
-import { type UseMutationOptions, queryOptions } from "@tanstack/react-query";
-import { CircleAlert } from "lucide-react";
-import type React from "react";
-import { Fragment } from "react";
 
 export type RequestedOperation =
 	| {
@@ -243,6 +243,12 @@ function showToast(requested: RequestedOperation) {
 	}
 }
 
+const TypographyItem = ({ children }: { children: React.ReactNode }) => (
+	<div className={"p-3"}>
+		<p className={"font-normal"}>{children}</p>
+	</div>
+);
+
 function ProjectChangesDialog({
 	changes,
 	existingPackages,
@@ -260,12 +266,6 @@ function ProjectChangesDialog({
 		([_, c]) => c.unlocked_names,
 	);
 
-	const TypographyItem = ({ children }: { children: React.ReactNode }) => (
-		<div className={"p-3"}>
-			<p className={"font-normal"}>{children}</p>
-		</div>
-	);
-
 	const existingPackageMap = new Map(existingPackages ?? []);
 
 	const categorizedChanges = changes.package_changes.map(([pkgId, change]) =>
@@ -760,13 +760,6 @@ function ChangelogButton({ url }: { url?: string | null }) {
 	return null;
 }
 
-function comparePackageChangeByName(
-	[aName]: [string, TauriPackageChange],
-	[bName]: [string, TauriPackageChange],
-): number {
-	return aName.localeCompare(bName);
-}
-
 function MissingDependenciesDialog({
 	dependencies,
 	dialog,
